@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -279,7 +279,8 @@ sub _init_options {
 
     # default to API settings if no command line option
     for(qw(config help version)) {
-        $options{$_} ||= $hash{$_}  if(defined $hash{$_});
+        next    unless(!defined $options{$_} && defined $hash{$_});
+        $options{$_} = $hash{$_};
     }
 
     $self->help(1)  if($options{help});
@@ -454,7 +455,7 @@ F<http://blog.cpantesters.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2009-2012 Barbie for Miss Barbell Productions.
+  Copyright (C) 2009-2014 Barbie for Miss Barbell Productions.
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
